@@ -7,7 +7,7 @@ __copyright__ = '2009, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 import sys, os, shutil, platform, subprocess, stat, py_compile, glob, \
-        textwrap, tarfile
+        textwrap, tarfile, re
 
 from setup import Command, modules, basenames, functions, __version__, \
     __appname__
@@ -19,11 +19,12 @@ SITE_PACKAGES = ['IPython', 'PIL', 'dateutil', 'dns', 'PyQt4', 'mechanize',
 
 QTDIR          = '/usr/lib/qt4'
 QTDLLS         = ('QtCore', 'QtGui', 'QtNetwork', 'QtSvg', 'QtXml', 'QtWebKit', 'QtDBus')
-
+MAGICK_PREFIX = '/usr'
 binary_includes = [
                 '/usr/bin/pdftohtml',
                 '/usr/lib/libwmflite-0.2.so.7',
                 '/usr/lib/liblcms.so.1',
+                '/usr/lib/liblzma.so.0',
                 '/usr/lib/libunrar.so',
                 '/usr/lib/libsqlite3.so.0',
                 '/usr/lib/libmng.so.1',
@@ -40,8 +41,8 @@ binary_includes = [
                 '/usr/lib/libgthread-2.0.so.0',
                 '/usr/lib/libpng14.so.14',
                 '/usr/lib/libexslt.so.0',
-                '/usr/lib/libMagickWand.so.4',
-                '/usr/lib/libMagickCore.so.4',
+                MAGICK_PREFIX+'/lib/libMagickWand.so.4',
+                MAGICK_PREFIX+'/lib/libMagickCore.so.4',
                 '/usr/lib/libgcrypt.so.11',
                 '/usr/lib/libgpg-error.so.0',
                 '/usr/lib/libphonon.so.4',
@@ -115,9 +116,25 @@ class LinuxFreeze(Command):
             if x not in ('designer', 'sqldrivers', 'codecs'):
                 shutil.copytree(y, self.j(dest, x))
 
-        im = glob.glob('/usr/lib/ImageMagick-*')[0]
-        dest = self.j(self.lib_dir, 'ImageMagick')
+        im = glob.glob(MAGICK_PREFIX + '/lib/ImageMagick-*')[-1]
+        self.magick_base = os.path.basename(im)
+        dest = self.j(self.lib_dir, self.magick_base)
         shutil.copytree(im, dest, ignore=shutil.ignore_patterns('*.a'))
+        from calibre import walk
+        for x in walk(dest):
+            if x.endswith('.la'):
+                raw = open(x).read()
+                raw = re.sub('libdir=.*', '', raw)
+                open(x, 'wb').write(raw)
+
+        dest = self.j(dest, 'config')
+        src = self.j(MAGICK_PREFIX, 'share', self.magick_base, 'config')
+        for x in glob.glob(src+'/*'):
+            d = self.j(dest, os.path.basename(x))
+            if os.path.isdir(x):
+                shutil.copytree(x, d)
+            else:
+                shutil.copyfile(x, d)
 
     def compile_mount_helper(self):
         self.info('Compiling mount helper...')
@@ -277,9 +294,10 @@ class LinuxFreeze(Command):
                 base=`dirname $path`
                 lib=$base/lib
                 export LD_LIBRARY_PATH=$lib:$LD_LIBRARY_PATH
-                export MAGICK_CONFIGURE_PATH=$lib/ImageMagick/config
-                export MAGICK_CODER_MODULE_PATH=$lib/ImageMagick/modules-Q16/coders
-                export MAGICK_CODER_FILTER_PATH=$lib/ImageMagick/modules-Q16/filters
+                export MAGICK_HOME=$base
+                export MAGICK_CONFIGURE_PATH=$lib/{1}/config
+                export MAGICK_CODER_MODULE_PATH=$lib/{1}/modules-Q16/coders
+                export MAGICK_CODER_FILTER_PATH=$lib/{1}/modules-Q16/filters
                 $base/bin/{0} "$@"
                 ''')
 
@@ -291,7 +309,7 @@ class LinuxFreeze(Command):
                 exe = self.j(self.bin_dir, bname)
                 sh = self.j(self.base, bname)
                 with open(sh, 'wb') as f:
-                    f.write(launcher.format(bname))
+                    f.write(launcher.format(bname, self.magick_base))
                 os.chmod(sh,
                     stat.S_IREAD|stat.S_IEXEC|stat.S_IWRITE|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
 
