@@ -216,9 +216,26 @@ def store_plugins():
     customization = config['plugin_customization']
     for plugin in _initialized_plugins:
         if isinstance(plugin, Store):
-            if not is_disabled(plugin):
-                plugin.site_customization = customization.get(plugin.name, '')
-                yield plugin
+            plugin.site_customization = customization.get(plugin.name, '')
+            yield plugin
+
+def available_store_plugins():
+    for plugin in store_plugins():
+        if not is_disabled(plugin):
+            yield plugin
+
+def stores():
+    stores = set([])
+    for plugin in store_plugins():
+        stores.add(plugin.name)
+    return stores
+
+def available_stores():
+    stores = set([])
+    for plugin in available_store_plugins():
+        stores.add(plugin.name)
+    return stores
+
 # }}}
 
 # Metadata read/write {{{
@@ -338,11 +355,17 @@ def remove_plugin(plugin_or_name):
     name = getattr(plugin_or_name, 'name', plugin_or_name)
     plugins = config['plugins']
     removed = False
-    if name in plugins.keys():
+    if name in plugins:
         removed = True
-        zfp = plugins[name]
-        if os.path.exists(zfp):
-            os.remove(zfp)
+        try:
+            zfp = os.path.join(plugin_dir, name+'.zip')
+            if os.path.exists(zfp):
+                os.remove(zfp)
+            zfp = plugins[name]
+            if os.path.exists(zfp):
+                os.remove(zfp)
+        except:
+            pass
         plugins.pop(name)
     config['plugins'] = plugins
     initialize_plugins()
@@ -470,6 +493,8 @@ def initialize_plugin(plugin, path_to_zip_file):
         raise InvalidPlugin((_('Initialization of plugin %s failed with traceback:')
                             %tb) + '\n'+tb)
 
+def has_external_plugins():
+    return bool(config['plugins'])
 
 def initialize_plugins():
     global _initialized_plugins
@@ -478,8 +503,15 @@ def initialize_plugins():
             builtin_names]
     for p in conflicts:
         remove_plugin(p)
-    for zfp in list(config['plugins'].itervalues()) + builtin_plugins:
+    external_plugins = config['plugins']
+    for zfp in list(external_plugins) + builtin_plugins:
         try:
+            if not isinstance(zfp, type):
+                # We have a plugin name
+                pname = zfp
+                zfp = os.path.join(plugin_dir, zfp+'.zip')
+                if not os.path.exists(zfp):
+                    zfp = external_plugins[pname]
             try:
                 plugin = load_plugin(zfp) if not isinstance(zfp, type) else zfp
             except PluginNotFound:
