@@ -26,9 +26,9 @@ class EDGE(USBMS):
     PRODUCT_ID  = [0x0c02]
     BCD         = [0x0223]
 
-    VENDOR_NAME = 'ANDROID'
-    WINDOWS_MAIN_MEM = '__FILE-STOR_GADG'
-    WINDOWS_CARD_A_MEM = '__FILE-STOR_GADG'
+    VENDOR_NAME = ['ANDROID', 'LINUX']
+    WINDOWS_MAIN_MEM = ['__FILE-STOR_GADG', 'FILE-CD_GADGET']
+    WINDOWS_CARD_A_MEM = ['__FILE-STOR_GADG', 'FILE-CD_GADGET']
 
     MAIN_MEMORY_VOLUME_LABEL  = 'Edge Main Memory'
     STORAGE_CARD_VOLUME_LABEL = 'Edge Storage Card'
