@@ -7,7 +7,7 @@ Code for the conversion of ebook formats and the reading of metadata
 from various formats.
 '''
 
-import traceback, os
+import traceback, os, re
 from calibre import CurrentDir
 
 class ConversionError(Exception):
@@ -26,7 +26,7 @@ class ParserError(ValueError):
     pass
 
 BOOK_EXTENSIONS = ['lrf', 'rar', 'zip', 'rtf', 'lit', 'txt', 'txtz', 'text', 'htm', 'xhtm',
-                   'html', 'xhtml', 'pdf', 'pdb', 'pdr', 'prc', 'mobi', 'azw', 'doc',
+                   'html', 'htmlz', 'xhtml', 'pdf', 'pdb', 'pdr', 'prc', 'mobi', 'azw', 'doc',
                    'epub', 'fb2', 'djvu', 'lrx', 'cbr', 'cbz', 'cbc', 'oebzip',
                    'rb', 'imp', 'odt', 'chm', 'tpz', 'azw1', 'pml', 'pmlz', 'mbp', 'tan', 'snb']
 
@@ -57,7 +57,7 @@ class HTMLRenderer(object):
             buf.open(QBuffer.WriteOnly)
             image.save(buf, 'JPEG')
             self.data = str(ba.data())
-        except Exception, e:
+        except Exception as e:
             self.exception = e
             self.traceback = traceback.format_exc()
         finally:
@@ -169,3 +169,42 @@ def calibre_cover(title, author_string, series_string=None,
         lines.append(TextLine(series_string, author_size))
     return create_cover_page(lines, I('library.png'), output_format='jpg')
 
+UNIT_RE = re.compile(r'^(-*[0-9]*[.]?[0-9]*)\s*(%|em|ex|en|px|mm|cm|in|pt|pc)$')
+
+def unit_convert(value, base, font, dpi):
+    ' Return value in pts'
+    if isinstance(value, (int, long, float)):
+        return value
+    try:
+        return float(value) * 72.0 / dpi
+    except:
+        pass
+    result = value
+    m = UNIT_RE.match(value)
+    if m is not None and m.group(1):
+        value = float(m.group(1))
+        unit = m.group(2)
+        if unit == '%':
+            result = (value / 100.0) * base
+        elif unit == 'px':
+            result = value * 72.0 / dpi
+        elif unit == 'in':
+            result = value * 72.0
+        elif unit == 'pt':
+            result = value
+        elif unit == 'em':
+            result = value * font
+        elif unit in ('ex', 'en'):
+            # This is a hack for ex since we have no way to know
+            # the x-height of the font
+            font = font
+            result = value * font * 0.5
+        elif unit == 'pc':
+            result = value * 12.0
+        elif unit == 'mm':
+            result = value * 0.04
+        elif unit == 'cm':
+            result = value * 0.40
+    return result
+
+
