@@ -26,6 +26,10 @@ class Epubcheck(ePubFixer):
                 'significant changes to your epub, complain to the epubcheck '
                 'project.')
 
+    @property
+    def description(self):
+        return self.long_description
+
     @property
     def fix_name(self):
         return 'epubcheck'
