@@ -20,7 +20,7 @@ from itertools import izip
 from calibre.customize.conversion import InputFormatPlugin
 from calibre.ebooks.chardet import xml_to_unicode
 from calibre.customize.conversion import OptionRecommendation
-from calibre.constants import islinux, isfreebsd, iswindows
+from calibre.constants import islinux, isbsd, iswindows
 from calibre import unicode_path, as_unicode
 from calibre.utils.localization import get_lang
 from calibre.utils.filenames import ascii_filename
@@ -302,7 +302,7 @@ class HTMLInput(InputFormatPlugin):
         if getattr(self, '_is_case_sensitive', None) is not None:
             return self._is_case_sensitive
         if not path or not os.path.exists(path):
-            return islinux or isfreebsd
+            return islinux or isbsd
         self._is_case_sensitive = not (os.path.exists(path.lower()) \
                 and os.path.exists(path.upper()))
         return self._is_case_sensitive
@@ -455,13 +455,16 @@ class HTMLInput(InputFormatPlugin):
             bhref = os.path.basename(link)
             id, href = self.oeb.manifest.generate(id='added',
                     href=bhref)
+            guessed = self.guess_type(href)[0]
+            media_type = guessed or self.BINARY_MIME
+            if media_type == 'text/plain':
+                self.log.warn('Ignoring link to text file %r'%link_)
+                return None
+
             self.oeb.log.debug('Added', link)
             self.oeb.container = self.DirContainer(os.path.dirname(link),
                     self.oeb.log, ignore_opf=True)
             # Load into memory
-            guessed = self.guess_type(href)[0]
-            media_type = guessed or self.BINARY_MIME
-
             item = self.oeb.manifest.add(id, href, media_type)
             item.html_input_href = bhref
             if guessed in self.OEB_STYLES:
