@@ -34,6 +34,7 @@ NULL_VALUES = {
                 'authors'      : [_('Unknown')],
                 'title'        : _('Unknown'),
                 'user_categories' : {},
+                'author_link_map' : {},
                 'language'     : 'und'
 }
 
@@ -41,28 +42,36 @@ field_metadata = FieldMetadata()
 
 class SafeFormat(TemplateFormatter):
 
-    def get_value(self, key, args, kwargs):
+    def get_value(self, orig_key, args, kwargs):
+        if not orig_key:
+            return ''
+        orig_key = orig_key.lower()
+        key = orig_key
+        if key != 'title_sort' and key not in TOP_LEVEL_IDENTIFIERS:
+            key = field_metadata.search_term_to_field_key(key)
+            if key is None or (self.book and
+                                key not in self.book.all_field_keys()):
+                if hasattr(self.book, orig_key):
+                    key = orig_key
+                else:
+                    raise ValueError(_('Value: unknown field ') + orig_key)
         try:
-            key = key.lower()
-            if key != 'title_sort' and key not in TOP_LEVEL_IDENTIFIERS:
-                key = field_metadata.search_term_to_field_key(key)
             b = self.book.get_user_metadata(key, False)
-            if b and b['datatype'] == 'int' and self.book.get(key, 0) == 0:
-                v = ''
-            elif b and b['datatype'] == 'float' and self.book.get(key, 0.0) == 0.0:
-                v = ''
-            else:
-                v = self.book.format_field(key, series_with_index=False)[1]
-            if v is None:
-                return ''
-            if v == '':
-                return ''
-            return v
         except:
-            if DEBUG:
-                traceback.print_exc()
-            return key
+            b = None
+        if b and b['datatype'] == 'int' and self.book.get(key, 0) == 0:
+            v = ''
+        elif b and b['datatype'] == 'float' and self.book.get(key, 0.0) == 0.0:
+            v = ''
+        else:
+            v = self.book.format_field(key, series_with_index=False)[1]
+        if v is None:
+            return ''
+        if v == '':
+            return ''
+        return v
 
+# DEPRECATED. This is not thread safe. Do not use.
 composite_formatter = SafeFormat()
 
 class Metadata(object):
@@ -75,7 +84,7 @@ class Metadata(object):
     Metadata from custom columns should be accessed via the get() method,
     passing in the lookup name for the column, for example: "#mytags".
 
-    Use the :meth:`is_null` method to test if a filed is null.
+    Use the :meth:`is_null` method to test if a field is null.
 
     This object also has functions to format fields into strings.
 
@@ -103,10 +112,11 @@ class Metadata(object):
                 # List of strings or []
                 self.author = list(authors) if authors else []# Needed for backward compatibility
                 self.authors = list(authors) if authors else []
+        self.formatter = SafeFormat()
 
     def is_null(self, field):
         '''
-        Return True if the value of filed is null in this object.
+        Return True if the value of field is null in this object.
         'null' means it is unknown or evaluates to False. So a title of
         _('Unknown') is null or a language of 'und' is null.
 
@@ -139,7 +149,7 @@ class Metadata(object):
                 return val
             if val is None:
                 d['#value#'] = 'RECURSIVE_COMPOSITE FIELD (Metadata) ' + field
-                val = d['#value#'] = composite_formatter.safe_format(
+                val = d['#value#'] = self.formatter.safe_format(
                                             d['display']['composite_template'],
                                             self,
                                             _('TEMPLATE ERROR'),
@@ -416,11 +426,12 @@ class Metadata(object):
         '''
         if not ops:
             return
+        formatter = SafeFormat()
         for op in ops:
             try:
                 src = op[0]
                 dest = op[1]
-                val = composite_formatter.safe_format\
+                val = formatter.safe_format\
                     (src, other, 'PLUGBOARD TEMPLATE ERROR', other)
                 if dest == 'tags':
                     self.set(dest, [f.strip() for f in val.split(',') if f.strip()])
@@ -614,10 +625,7 @@ class Metadata(object):
             orig_res = res
             datatype = cmeta['datatype']
             if datatype == 'text' and cmeta['is_multiple']:
-                if cmeta['display'].get('is_names', False):
-                    res = u' & '.join(res)
-                else:
-                    res = u', '.join(sorted(res, key=sort_key))
+                res = cmeta['is_multiple']['list_to_ui'].join(res)
             elif datatype == 'series' and series_with_index:
                 if self.get_extra(key) is not None:
                     res = res + \
@@ -628,6 +636,12 @@ class Metadata(object):
                 res = _('Yes') if res else _('No')
             elif datatype == 'rating':
                 res = res/2.0
+            elif datatype in ['int', 'float']:
+                try:
+                    fmt = cmeta['display'].get('number_format', None)
+                    res = fmt.format(res)
+                except:
+                    pass
             return (name, unicode(res), orig_res, cmeta)
 
         # convert top-level ids into their value
@@ -655,7 +669,7 @@ class Metadata(object):
             elif datatype == 'text' and fmeta['is_multiple']:
                 if isinstance(res, dict):
                     res = [k + ':' + v for k,v in res.items()]
-                res = u', '.join(sorted(res, key=sort_key))
+                res = fmeta['is_multiple']['list_to_ui'].join(sorted(res, key=sort_key))
             elif datatype == 'series' and series_with_index:
                 res = res + ' [%s]'%self.format_series_index()
             elif datatype == 'datetime':
