@@ -259,6 +259,7 @@ class MetadataUpdater(object):
         trail = len(new_record0.getvalue()) % 4
         pad = '\0' * (4 - trail) # Always pad w/ at least 1 byte
         new_record0.write(pad)
+        new_record0.write('\0'*(1024*8))
 
         # Rebuild the stream, update the pdbrecords pointers
         self.patchSection(0,new_record0.getvalue())
@@ -271,11 +272,11 @@ class MetadataUpdater(object):
         FILTER=''.join([(len(repr(chr(x)))==3) and chr(x) or '.' for x in range(256)])
         N=0; result=''
         while src:
-           s,src = src[:length],src[length:]
-           hexa = ' '.join(["%02X"%ord(x) for x in s])
-           s = s.translate(FILTER)
-           result += "%04X   %-*s   %s\n" % (N, length*3, hexa, s)
-           N+=length
+            s,src = src[:length],src[length:]
+            hexa = ' '.join(["%02X"%ord(x) for x in s])
+            s = s.translate(FILTER)
+            result += "%04X   %-*s   %s\n" % (N, length*3, hexa, s)
+            N+=length
         print result
 
     def get_pdbrecords(self):
@@ -323,6 +324,7 @@ class MetadataUpdater(object):
                                 "\tThis is a '%s' file of type '%s'" % (self.type[0:4], self.type[4:8]))
 
         recs = []
+        added_501 = False
         try:
             from calibre.ebooks.conversion.config import load_defaults
             prefs = load_defaults('mobi_output')
@@ -355,6 +357,7 @@ class MetadataUpdater(object):
             update_exth_record((105, normalize(subjects).encode(self.codec, 'replace')))
 
             if kindle_pdoc and kindle_pdoc in mi.tags:
+                added_501 = True
                 update_exth_record((501, str('PDOC')))
 
         if mi.pubdate:
@@ -370,6 +373,12 @@ class MetadataUpdater(object):
             update_exth_record((203, pack('>I', 0)))
         if self.thumbnail_record is not None:
             update_exth_record((202, pack('>I', self.thumbnail_rindex)))
+        # Add a 113 record if not present to allow Amazon syncing
+        if (113 not in self.original_exth_records and
+                self.original_exth_records.get(501, None) == 'EBOK' and
+                not added_501):
+            from uuid import uuid4
+            update_exth_record((113, str(uuid4())))
         if 503 in self.original_exth_records:
             update_exth_record((503, mi.title.encode(self.codec, 'replace')))
 
@@ -391,7 +400,8 @@ class MetadataUpdater(object):
         if getattr(self, 'exth', None) is None:
             raise MobiError('No existing EXTH record. Cannot update metadata.')
 
-        self.record0[92:96] = iana2mobi(mi.language)
+        if not mi.is_null('language'):
+            self.record0[92:96] = iana2mobi(mi.language)
         self.create_exth(exth=exth, new_title=mi.title)
 
         # Fetch updated timestamp, cover_record, thumbnail_record
