@@ -85,7 +85,11 @@ class ISBNMerge(object):
                 isbns, min_year = xisbn.get_isbn_pool(isbn)
                 if not isbns:
                     isbns = frozenset([isbn])
-                self.pools[isbns] = pool = (min_year, [])
+                if isbns in self.pools:
+                    # xISBN had a brain fart
+                    pool = self.pools[isbns]
+                else:
+                    self.pools[isbns] = pool = (min_year, [])
 
             if not self.pool_has_result_from_same_source(pool, result):
                 pool[1].append(result)
@@ -408,6 +412,8 @@ def identify(log, abort, # {{{
             for f in plugin.prefs['ignore_fields']:
                 if ':' not in f:
                     setattr(result, f, getattr(dummy, f))
+                if f == 'series':
+                    result.series_index = dummy.series_index
             result.relevance_in_source = i
             result.has_cached_cover_url = (plugin.cached_cover_url_is_reliable
                     and plugin.get_cached_cover_url(result.identifiers) is not
