@@ -10,11 +10,9 @@ import sys, os, uuid, copy, re, cStringIO
 from itertools import izip
 from urlparse import urldefrag, urlparse
 from urllib import unquote as urlunquote
-from mimetypes import guess_type
 from collections import defaultdict
 
 from lxml import etree
-import cssutils
 
 from calibre.ebooks.oeb.base import OPF1_NS, OPF2_NS, OPF2_NSMAP, DC11_NS, \
     DC_NSES, OPF, xml2text
@@ -30,6 +28,7 @@ from calibre.ebooks.oeb.entitydefs import ENTITYDEFS
 from calibre.utils.localization import get_lang
 from calibre.ptempfile import TemporaryDirectory
 from calibre.constants import __appname__, __version__
+from calibre import guess_type
 
 __all__ = ['OEBReader']
 
@@ -103,6 +102,8 @@ class OEBReader(object):
         data = self.oeb.container.read(None)
         data = self.oeb.decode(data)
         data = XMLDECL_RE.sub('', data)
+        data = re.sub(r'http://openebook.org/namespaces/oeb-package/1.0(/*)',
+                OPF1_NS, data)
         try:
             opf = etree.fromstring(data)
         except etree.XMLSyntaxError:
@@ -170,6 +171,7 @@ class OEBReader(object):
         return bad
 
     def _manifest_add_missing(self, invalid):
+        import cssutils
         manifest = self.oeb.manifest
         known = set(manifest.hrefs)
         unchecked = set(manifest.values())
@@ -189,7 +191,11 @@ class OEBReader(object):
                         if not scheme and href not in known:
                             new.add(href)
                 elif item.media_type in OEB_STYLES:
-                    for url in cssutils.getUrls(item.data):
+                    try:
+                        urls = list(cssutils.getUrls(item.data))
+                    except:
+                        urls = []
+                    for url in urls:
                         href, _ = urldefrag(url)
                         href = item.abshref(urlnormalize(href))
                         scheme = urlparse(href).scheme
