@@ -141,8 +141,8 @@ class CoverManager(object):
             if width is None or height is None:
                 self.log.warning('Failed to read cover dimensions')
                 width, height = 600, 800
-            if self.preserve_aspect_ratio:
-                width, height = 600, 800
+            #if self.preserve_aspect_ratio:
+            #    width, height = 600, 800
             self.svg_template = self.svg_template.replace('__viewbox__',
                     '0 0 %d %d'%(width, height))
             self.svg_template = self.svg_template.replace('__width__',
