@@ -197,8 +197,8 @@ class ProcessTokens:
         # character info => ci
         'b'                  :	('ci', 'bold______', self.bool_st_func),
         'blue'               :	('ci', 'blue______', self.color_func),
-        'caps'               :  ('ci', 'caps______', self.bool_st_func),
-        'cf'                 :	('ci', 'font-color', self.default_func),
+        'caps'               :	('ci', 'caps______', self.bool_st_func),
+        'cf'                 :	('ci', 'font-color', self.colorz_func),
         'chftn'              :	('ci', 'footnot-mk', self.bool_st_func),
         'dn'                 :	('ci', 'font-down_', self.divide_by_2),
         'embo'               :	('ci', 'emboss____', self.bool_st_func),
@@ -624,6 +624,11 @@ class ProcessTokens:
             num = 'true'
         return 'cw<%s<%s<nu<%s\n' % (pre, token, num)
 
+    def colorz_func(self, pre, token, num):
+        if num is None:
+            num = '0'
+        return 'cw<%s<%s<nu<%s\n' % (pre, token, num)
+
     def __list_type_func(self, pre, token, num):
         type = 'arabic'
         if num is None:
@@ -786,21 +791,23 @@ class ProcessTokens:
                     token = line.replace("\n","")
                     line_count += 1
                     if line_count == 1 and token != '\\{':
-                            msg = 'Invalid RTF: document doesn\'t start with {\n'
+                            msg = '\nInvalid RTF: document doesn\'t start with {\n'
                             raise self.__exception_handler, msg
                     elif line_count == 2 and token[0:4] != '\\rtf':
-                            msg = 'Invalid RTF: document doesn\'t start with \\rtf \n'
+                            msg = '\nInvalid RTF: document doesn\'t start with \\rtf \n'
                             raise self.__exception_handler, msg
 
                     the_index = token.find('\\ ')
                     if token is not None and  the_index > -1:
-                        msg = 'Invalid RTF: token "\\ " not valid.\n'
+                        msg = '\nInvalid RTF: token "\\ " not valid.\nError at line %d'\
+                            % line_count
                         raise self.__exception_handler, msg
                     elif token[:1] == "\\":
                         try:
                             token.decode('us-ascii')
                         except UnicodeError, msg:
-                            msg = 'Invalid RTF: Tokens not ascii encoded.\n%s' % str(msg)
+                            msg = '\nInvalid RTF: Tokens not ascii encoded.\n%s\nError at line %d'\
+                                % (str(msg), line_count)
                             raise self.__exception_handler, msg
                         line = self.process_cw(token)
                         if line is not None:
@@ -816,7 +823,7 @@ class ProcessTokens:
                                 write_obj.write('tx<nu<__________<%s\n' % field)
 
         if not line_count:
-            msg = 'Invalid RTF: file appears to be empty.\n'
+            msg = '\nInvalid RTF: file appears to be empty.\n'
             raise self.__exception_handler, msg
 
         copy_obj = copy.Copy(bug_handler = self.__bug_handler)
@@ -827,7 +834,7 @@ class ProcessTokens:
 
         bad_brackets = self.__check_brackets(self.__file)
         if bad_brackets:
-            msg = 'Invalid RTF: document does not have matching brackets.\n'
+            msg = '\nInvalid RTF: document does not have matching brackets.\n'
             raise self.__exception_handler, msg
         else:
             return self.__return_code
