@@ -13,7 +13,7 @@ class OpenFolderAction(InterfaceAction):
     name = 'Open Folder'
     action_spec = (_('Open containing folder'), 'document_open.png', None,
             _('O'))
-    dont_add_to = frozenset(['toolbar-device', 'context-menu-device'])
+    dont_add_to = frozenset(['menubar-device', 'toolbar-device', 'context-menu-device'])
     action_type = 'current'
 
     def genesis(self):
