@@ -21,7 +21,7 @@ class LookAndFeelWidget(Widget, Ui_Form):
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
         Widget.__init__(self, parent,
                 ['change_justification', 'extra_css', 'base_font_size',
-                    'font_size_mapping', 'line_height',
+                    'font_size_mapping', 'line_height', 'minimum_line_height',
                     'linearize_tables', 'smarten_punctuation',
                     'disable_font_rescaling', 'insert_blank_line',
                     'remove_paragraph_spacing', 'remove_paragraph_spacing_indent_size','input_encoding',
