@@ -192,7 +192,7 @@ class MetadataWidget(Widget, Ui_Form):
             try:
                 cf = open(_file, "rb")
                 cover = cf.read()
-            except IOError, e:
+            except IOError as e:
                 d = error_dialog(self.parent(), _('Error reading file'),
                         _("<p>There was an error reading from file: <br /><b>") + _file + "</b></p><br />"+str(e))
                 d.exec_()
