@@ -6,18 +6,18 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 import os, traceback, Queue, time, cStringIO, re, sys
 from threading import Thread
 
-from PyQt4.Qt import QMenu, QAction, QActionGroup, QIcon, SIGNAL, \
-                     Qt, pyqtSignal, QDialog, QObject
+from PyQt4.Qt import (QMenu, QAction, QActionGroup, QIcon, SIGNAL,
+                     Qt, pyqtSignal, QDialog, QObject)
 
-from calibre.customize.ui import available_input_formats, available_output_formats, \
-    device_plugins
+from calibre.customize.ui import (available_input_formats, available_output_formats,
+    device_plugins)
 from calibre.devices.interface import DevicePlugin
 from calibre.devices.errors import UserFeedback, OpenFeedback
 from calibre.gui2.dialogs.choose_format_device import ChooseFormatDeviceDialog
 from calibre.utils.ipc.job import BaseJob
 from calibre.devices.scanner import DeviceScanner
-from calibre.gui2 import config, error_dialog, Dispatcher, dynamic, \
-        warning_dialog, info_dialog, choose_dir
+from calibre.gui2 import (config, error_dialog, Dispatcher, dynamic,
+        warning_dialog, info_dialog, choose_dir, FunctionDispatcher)
 from calibre.ebooks.metadata import authors_to_string
 from calibre import preferred_encoding, prints, force_unicode, as_unicode
 from calibre.utils.filenames import ascii_filename
@@ -35,8 +35,13 @@ class DeviceJob(BaseJob): # {{{
 
     def __init__(self, func, done, job_manager, args=[], kwargs={},
             description=''):
-        BaseJob.__init__(self, description, done=done)
+        BaseJob.__init__(self, description)
         self.func = func
+        self.callback_on_done = done
+        if not isinstance(self.callback_on_done, (Dispatcher,
+            FunctionDispatcher)):
+            self.callback_on_done = FunctionDispatcher(self.callback_on_done)
+
         self.args, self.kwargs = args, kwargs
         self.exception = None
         self.job_manager = job_manager
@@ -44,12 +49,26 @@ class DeviceJob(BaseJob): # {{{
         self._aborted = False
 
     def start_work(self):
+        if DEBUG:
+            prints('Job:', self.id, self.description, 'started',
+                safe_encode=True)
         self.start_time = time.time()
         self.job_manager.changed_queue.put(self)
 
     def job_done(self):
         self.duration = time.time() - self.start_time
         self.percent = 1
+        if DEBUG:
+            prints('DeviceJob:', self.id, self.description,
+                    'done, calling callback', safe_encode=True)
+
+        try:
+            self.callback_on_done(self)
+        except:
+            pass
+        if DEBUG:
+            prints('DeviceJob:', self.id, self.description,
+                    'callback returned', safe_encode=True)
         self.job_manager.changed_queue.put(self)
 
     def report_progress(self, percent, msg=''):
@@ -110,6 +129,7 @@ class DeviceManager(Thread): # {{{
         self.sleep_time     = sleep_time
         self.connected_slot = connected_slot
         self.jobs           = Queue.Queue(0)
+        self.job_steps      = Queue.Queue(0)
         self.keep_going     = True
         self.job_manager    = job_manager
         self.reported_errors = set([])
@@ -226,6 +246,12 @@ class DeviceManager(Thread): # {{{
                 self.connected_device.unmount_device()
 
     def next(self):
+        if not self.job_steps.empty():
+            try:
+                return self.job_steps.get_nowait()
+            except Queue.Empty:
+                pass
+
         if not self.jobs.empty():
             try:
                 return self.jobs.get_nowait()
@@ -254,20 +280,28 @@ class DeviceManager(Thread): # {{{
                 job = self.next()
                 if job is not None:
                     self.current_job = job
-                    self.device.set_progress_reporter(job.report_progress)
+                    if self.device is not None:
+                        self.device.set_progress_reporter(job.report_progress)
                     self.current_job.run()
                     self.current_job = None
                 else:
                     break
             time.sleep(self.sleep_time)
 
-    def create_job(self, func, done, description, args=[], kwargs={}):
+    def create_job_step(self, func, done, description, to_job, args=[], kwargs={}):
         job = DeviceJob(func, done, self.job_manager,
                         args=args, kwargs=kwargs, description=description)
         self.job_manager.add_job(job)
-        self.jobs.put(job)
+        if (done is None or isinstance(done, FunctionDispatcher)) and \
+                    (to_job is not None and to_job == self.current_job):
+            self.job_steps.put(job)
+        else:
+            self.jobs.put(job)
         return job
 
+    def create_job(self, func, done, description, args=[], kwargs={}):
+        return self.create_job_step(func, done, description, None, args, kwargs)
+
     def has_card(self):
         try:
             return bool(self.device.card_prefix())
@@ -285,10 +319,10 @@ class DeviceManager(Thread): # {{{
         self._device_information = {'info': info, 'prefixes': cp, 'freespace': fs}
         return info, cp, fs
 
-    def get_device_information(self, done):
+    def get_device_information(self, done, add_as_step_to_job=None):
         '''Get device information and free space on device'''
-        return self.create_job(self._get_device_information, done,
-                    description=_('Get device information'))
+        return self.create_job_step(self._get_device_information, done,
+                    description=_('Get device information'), to_job=add_as_step_to_job)
 
     def get_current_device_information(self):
         return self._device_information
@@ -300,36 +334,38 @@ class DeviceManager(Thread): # {{{
         cardblist = self.device.books(oncard='cardb')
         return (mainlist, cardalist, cardblist)
 
-    def books(self, done):
+    def books(self, done, add_as_step_to_job=None):
         '''Return callable that returns the list of books on device as two booklists'''
-        return self.create_job(self._books, done, description=_('Get list of books on device'))
+        return self.create_job_step(self._books, done,
+                description=_('Get list of books on device'), to_job=add_as_step_to_job)
 
     def _annotations(self, path_map):
         return self.device.get_annotations(path_map)
 
-    def annotations(self, done, path_map):
+    def annotations(self, done, path_map, add_as_step_to_job=None):
         '''Return mapping of ids to annotations. Each annotation is of the
         form (type, location_info, content). path_map is a mapping of
         ids to paths on the device.'''
-        return self.create_job(self._annotations, done, args=[path_map],
-                description=_('Get annotations from device'))
+        return self.create_job_step(self._annotations, done, args=[path_map],
+                description=_('Get annotations from device'), to_job=add_as_step_to_job)
 
     def _sync_booklists(self, booklists):
         '''Sync metadata to device'''
         self.device.sync_booklists(booklists, end_session=False)
         return self.device.card_prefix(end_session=False), self.device.free_space()
 
-    def sync_booklists(self, done, booklists, plugboards):
+    def sync_booklists(self, done, booklists, plugboards, add_as_step_to_job=None):
         if hasattr(self.connected_device, 'set_plugboards') and \
                 callable(self.connected_device.set_plugboards):
             self.connected_device.set_plugboards(plugboards, find_plugboard)
-        return self.create_job(self._sync_booklists, done, args=[booklists],
-                        description=_('Send metadata to device'))
+        return self.create_job_step(self._sync_booklists, done, args=[booklists],
+                        description=_('Send metadata to device'), to_job=add_as_step_to_job)
 
-    def upload_collections(self, done, booklist, on_card):
-        return self.create_job(booklist.rebuild_collections, done,
+    def upload_collections(self, done, booklist, on_card, add_as_step_to_job=None):
+        return self.create_job_step(booklist.rebuild_collections, done,
                                args=[booklist, on_card],
-                        description=_('Send collections to device'))
+                        description=_('Send collections to device'),
+                        to_job=add_as_step_to_job)
 
     def _upload_books(self, files, names, on_card=None, metadata=None, plugboards=None):
         '''Upload books to device: '''
@@ -360,15 +396,25 @@ class DeviceManager(Thread): # {{{
                             if DEBUG:
                                 prints(traceback.format_exc(), file=sys.__stdout__)
 
-        return self.device.upload_books(files, names, on_card,
-                                        metadata=metadata, end_session=False)
+        try:
+            return self.device.upload_books(files, names, on_card,
+                    metadata=metadata, end_session=False)
+        finally:
+            if metadata:
+                for mi in metadata:
+                    try:
+                        if mi.cover:
+                            os.remove(mi.cover)
+                    except:
+                        pass
 
     def upload_books(self, done, files, names, on_card=None, titles=None,
-                     metadata=None, plugboards=None):
+                     metadata=None, plugboards=None, add_as_step_to_job=None):
         desc = _('Upload %d books to device')%len(names)
         if titles:
             desc += u':' + u', '.join(titles)
-        return self.create_job(self._upload_books, done, args=[files, names],
+        return self.create_job_step(self._upload_books, done, to_job=add_as_step_to_job,
+                               args=[files, names],
                 kwargs={'on_card':on_card,'metadata':metadata,'plugboards':plugboards}, description=desc)
 
     def add_books_to_metadata(self, locations, metadata, booklists):
@@ -378,9 +424,10 @@ class DeviceManager(Thread): # {{{
         '''Remove books from device'''
         self.device.delete_books(paths, end_session=True)
 
-    def delete_books(self, done, paths):
-        return self.create_job(self._delete_books, done, args=[paths],
-                        description=_('Delete books from device'))
+    def delete_books(self, done, paths, add_as_step_to_job=None):
+        return self.create_job_step(self._delete_books, done, args=[paths],
+                        description=_('Delete books from device'),
+                        to_job=add_as_step_to_job)
 
     def remove_books_from_metadata(self, paths, booklists):
         self.device.remove_books_from_metadata(paths, booklists)
@@ -395,9 +442,10 @@ class DeviceManager(Thread): # {{{
                 self.device.get_file(path, f)
                 f.close()
 
-    def save_books(self, done, paths, target):
-        return self.create_job(self._save_books, done, args=[paths, target],
-                        description=_('Download books from device'))
+    def save_books(self, done, paths, target, add_as_step_to_job=None):
+        return self.create_job_step(self._save_books, done, args=[paths, target],
+                        description=_('Download books from device'),
+                        to_job=add_as_step_to_job)
 
     def _view_book(self, path, target):
         f = open(target, 'wb')
@@ -405,9 +453,9 @@ class DeviceManager(Thread): # {{{
         f.close()
         return target
 
-    def view_book(self, done, path, target):
-        return self.create_job(self._view_book, done, args=[path, target],
-                        description=_('View book on device'))
+    def view_book(self, done, path, target, add_as_step_to_job=None):
+        return self.create_job_step(self._view_book, done, args=[path, target],
+                        description=_('View book on device'), to_job=add_as_step_to_job)
 
     def set_current_library_uuid(self, uuid):
         self.current_library_uuid = uuid
@@ -587,7 +635,7 @@ class DeviceMenu(QMenu): # {{{
 
     # }}}
 
-class DeviceSignals(QObject):
+class DeviceSignals(QObject): # {{{
     #: This signal is emitted once, after metadata is downloaded from the
     #: connected device.
     #: The sequence: gui.device_manager.is_device_connected will become True,
@@ -604,6 +652,7 @@ class DeviceSignals(QObject):
     device_connection_changed = pyqtSignal(object)
 
 device_signals = DeviceSignals()
+# }}}
 
 class DeviceMixin(object): # {{{
 
@@ -611,7 +660,7 @@ class DeviceMixin(object): # {{{
         self.device_error_dialog = error_dialog(self, _('Error'),
                 _('Error communicating with device'), ' ')
         self.device_error_dialog.setModal(Qt.NonModal)
-        self.device_manager = DeviceManager(Dispatcher(self.device_detected),
+        self.device_manager = DeviceManager(FunctionDispatcher(self.device_detected),
                 self.job_manager, Dispatcher(self.status_bar.show_message),
                 Dispatcher(self.show_open_feedback))
         self.device_manager.start()
@@ -736,7 +785,7 @@ class DeviceMixin(object): # {{{
         self.set_device_menu_items_state(connected)
         if connected:
             self.device_manager.get_device_information(\
-                    Dispatcher(self.info_read))
+                    FunctionDispatcher(self.info_read))
             self.set_default_thumbnail(\
                     self.device_manager.device.THUMBNAIL_HEIGHT)
             self.status_bar.show_message(_('Device: ')+\
@@ -767,7 +816,8 @@ class DeviceMixin(object): # {{{
                 self.device_manager.device.icon)
         self.bars_manager.update_bars()
         self.status_bar.device_connected(info[0])
-        self.device_manager.books(Dispatcher(self.metadata_downloaded))
+        self.device_manager.books(FunctionDispatcher(self.metadata_downloaded),
+                                  add_as_step_to_job=job)
 
     def metadata_downloaded(self, job):
         '''
@@ -777,7 +827,7 @@ class DeviceMixin(object): # {{{
             self.device_job_exception(job)
             return
         # set_books_in_library might schedule a sync_booklists job
-        self.set_books_in_library(job.result, reset=True)
+        self.set_books_in_library(job.result, reset=True, add_as_step_to_job=job)
         mainlist, cardalist, cardblist = job.result
         self.memory_view.set_database(mainlist)
         self.memory_view.set_editable(self.device_manager.device.CAN_SET_METADATA,
@@ -810,7 +860,7 @@ class DeviceMixin(object): # {{{
 
     def remove_paths(self, paths):
         return self.device_manager.delete_books(
-                Dispatcher(self.books_deleted), paths)
+                FunctionDispatcher(self.books_deleted), paths)
 
     def books_deleted(self, job):
         '''
@@ -832,8 +882,8 @@ class DeviceMixin(object): # {{{
         # set_books_in_library even though books were not added because
         # the deleted book might have been an exact match. Upload the booklists
         # if set_books_in_library did not.
-        if not self.set_books_in_library(self.booklists(), reset=True):
-            self.upload_booklists()
+        if not self.set_books_in_library(self.booklists(), reset=True, add_as_step_to_job=job):
+            self.upload_booklists(job)
         self.book_on_device(None, reset=True)
         # We need to reset the ondevice flags in the library. Use a big hammer,
         # so we don't need to worry about whether some succeeded or not.
@@ -1031,8 +1081,6 @@ class DeviceMixin(object): # {{{
                             'the device?'), autos):
                         self.iactions['Convert Books'].auto_convert_news(auto, format)
             files = [f for f in files if f is not None]
-            for f in files:
-                f.deleted_after_upload = del_on_upload
             if not files:
                 self.news_to_be_synced = set([])
                 return
@@ -1182,13 +1230,14 @@ class DeviceMixin(object): # {{{
         self.device_manager.sync_booklists(Dispatcher(lambda x: x),
                                            self.booklists(), plugboards)
 
-    def upload_booklists(self):
+    def upload_booklists(self, add_as_step_to_job=None):
         '''
         Upload metadata to device.
         '''
         plugboards = self.library_view.model().db.prefs.get('plugboards', {})
-        self.device_manager.sync_booklists(Dispatcher(self.metadata_synced),
-                                           self.booklists(), plugboards)
+        self.device_manager.sync_booklists(FunctionDispatcher(self.metadata_synced),
+                                           self.booklists(), plugboards,
+                                           add_as_step_to_job=add_as_step_to_job)
 
     def metadata_synced(self, job):
         '''
@@ -1222,7 +1271,7 @@ class DeviceMixin(object): # {{{
         titles = [i.title for i in metadata]
         plugboards = self.library_view.model().db.prefs.get('plugboards', {})
         job = self.device_manager.upload_books(
-                Dispatcher(self.books_uploaded),
+                FunctionDispatcher(self.books_uploaded),
                 files, names, on_card=on_card,
                 metadata=metadata, titles=titles, plugboards=plugboards
               )
@@ -1263,8 +1312,8 @@ class DeviceMixin(object): # {{{
         # because the UUID changed. Force both the device and the library view
         # to refresh the flags. Set_books_in_library could upload the booklists.
         # If it does not, then do it here.
-        if not self.set_books_in_library(self.booklists(), reset=True):
-            self.upload_booklists()
+        if not self.set_books_in_library(self.booklists(), reset=True, add_as_step_to_job=job):
+            self.upload_booklists(job)
         with self.library_view.preserve_selected_books:
             self.book_on_device(None, reset=True)
             self.refresh_ondevice()
@@ -1273,8 +1322,17 @@ class DeviceMixin(object): # {{{
             self.card_b_view if on_card == 'cardb' else self.memory_view
         view.model().resort(reset=False)
         view.model().research()
-        for f in files:
-            getattr(f, 'close', lambda : True)()
+        if files:
+            for f in files:
+                # Remove temporary files
+                try:
+                    rem = not getattr(
+                            self.device_manager.device,
+                            'KEEP_TEMP_FILES_AFTER_UPLOAD', False)
+                    if rem and 'caltmpfmt.' in f:
+                        os.remove(f)
+                except:
+                    pass
 
     def book_on_device(self, id, reset=False):
         '''
@@ -1294,7 +1352,8 @@ class DeviceMixin(object): # {{{
             self.book_db_uuid_path_map = None
             return
 
-        if not hasattr(self, 'db_book_uuid_cache'):
+        if not self.device_manager.is_device_connected or \
+                        not hasattr(self, 'db_book_uuid_cache'):
             return loc
 
         if self.book_db_id_cache is None:
@@ -1323,7 +1382,7 @@ class DeviceMixin(object): # {{{
                 loc[4] |= self.book_db_uuid_path_map[id]
         return loc
 
-    def set_books_in_library(self, booklists, reset=False):
+    def set_books_in_library(self, booklists, reset=False, add_as_step_to_job=None):
         '''
         Set the ondevice indications in the device database.
         This method should be called before book_on_device is called, because
@@ -1474,8 +1533,8 @@ class DeviceMixin(object): # {{{
                                     self.cover_to_thumbnail(open(book.cover, 'rb').read())
                 plugboards = self.library_view.model().db.prefs.get('plugboards', {})
                 self.device_manager.sync_booklists(
-                                    Dispatcher(self.metadata_synced), booklists,
-                                    plugboards)
+                                    FunctionDispatcher(self.metadata_synced), booklists,
+                                    plugboards, add_as_step_to_job)
         return update_metadata
     # }}}
 
