@@ -50,9 +50,16 @@ class FieldMetadata(dict):
 
     datatype: the type of information in the field. Valid values are listed in
     VALID_DATA_TYPES below.
-    is_multiple: valid for the text datatype. If None, the field is to be
-    treated as a single term. If not None, it contains a string, and the field
-    is assumed to contain a list of terms separated by that string
+    is_multiple: valid for the text datatype. If {}, the field is to be
+    treated as a single term. If not None, it contains a dict of the form
+            {'cache_to_list': ',',
+             'ui_to_list': ',',
+             'list_to_ui': ', '}
+    where the cache_to_list contains the character used to split the value in
+    the meta2 table, ui_to_list contains the character used to create a list
+    from a value shown in the ui (each resulting value must be strip()ed and
+    empty values removed), and list_to_ui contains the string used in join()
+    to create a displayable string from the list.
 
     kind == field: is a db field.
     kind == category: standard tag category that isn't a field. see news.
@@ -97,7 +104,9 @@ class FieldMetadata(dict):
                            'link_column':'author',
                            'category_sort':'sort',
                            'datatype':'text',
-                           'is_multiple':',',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': '&',
+                                          'list_to_ui': ' & '},
                            'kind':'field',
                            'name':_('Authors'),
                            'search_terms':['authors', 'author'],
@@ -109,7 +118,7 @@ class FieldMetadata(dict):
                            'link_column':'series',
                            'category_sort':'(title_sort(name))',
                            'datatype':'series',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Series'),
                            'search_terms':['series'],
@@ -119,7 +128,9 @@ class FieldMetadata(dict):
             ('formats',   {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':',',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
                            'kind':'field',
                            'name':_('Formats'),
                            'search_terms':['formats', 'format'],
@@ -131,7 +142,7 @@ class FieldMetadata(dict):
                            'link_column':'publisher',
                            'category_sort':'name',
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Publishers'),
                            'search_terms':['publisher'],
@@ -143,7 +154,7 @@ class FieldMetadata(dict):
                            'link_column':'rating',
                            'category_sort':'rating',
                            'datatype':'rating',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Ratings'),
                            'search_terms':['rating'],
@@ -154,7 +165,7 @@ class FieldMetadata(dict):
                            'column':'name',
                            'category_sort':'name',
                            'datatype':None,
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'category',
                            'name':_('News'),
                            'search_terms':[],
@@ -166,7 +177,9 @@ class FieldMetadata(dict):
                            'link_column': 'tag',
                            'category_sort':'name',
                            'datatype':'text',
-                           'is_multiple':',',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
                            'kind':'field',
                            'name':_('Tags'),
                            'search_terms':['tags', 'tag'],
@@ -176,7 +189,9 @@ class FieldMetadata(dict):
             ('identifiers',   {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':',',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
                            'kind':'field',
                            'name':_('Identifiers'),
                            'search_terms':['identifiers', 'identifier', 'isbn'],
@@ -186,7 +201,7 @@ class FieldMetadata(dict):
             ('author_sort',{'table':None,
                             'column':None,
                             'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Author Sort'),
                            'search_terms':['author_sort'],
@@ -196,7 +211,9 @@ class FieldMetadata(dict):
             ('au_map',    {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':',',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': None,
+                                          'list_to_ui': None},
                            'kind':'field',
                            'name':None,
                            'search_terms':[],
@@ -206,7 +223,7 @@ class FieldMetadata(dict):
             ('comments',  {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Comments'),
                            'search_terms':['comments', 'comment'],
@@ -216,7 +233,7 @@ class FieldMetadata(dict):
             ('cover',     {'table':None,
                            'column':None,
                            'datatype':'int',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':None,
                            'search_terms':['cover'],
@@ -226,7 +243,7 @@ class FieldMetadata(dict):
             ('id',        {'table':None,
                            'column':None,
                            'datatype':'int',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':None,
                            'search_terms':[],
@@ -236,7 +253,7 @@ class FieldMetadata(dict):
             ('last_modified', {'table':None,
                            'column':None,
                            'datatype':'datetime',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Modified'),
                            'search_terms':['last_modified'],
@@ -246,7 +263,7 @@ class FieldMetadata(dict):
             ('ondevice',  {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('On Device'),
                            'search_terms':['ondevice'],
@@ -256,7 +273,7 @@ class FieldMetadata(dict):
             ('path',      {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Path'),
                            'search_terms':[],
@@ -266,7 +283,7 @@ class FieldMetadata(dict):
             ('pubdate',   {'table':None,
                            'column':None,
                            'datatype':'datetime',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Published'),
                            'search_terms':['pubdate'],
@@ -276,7 +293,7 @@ class FieldMetadata(dict):
             ('marked',    {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name': None,
                            'search_terms':['marked'],
@@ -286,7 +303,7 @@ class FieldMetadata(dict):
             ('series_index',{'table':None,
                              'column':None,
                              'datatype':'float',
-                             'is_multiple':None,
+                             'is_multiple':{},
                              'kind':'field',
                              'name':None,
                              'search_terms':['series_index'],
@@ -296,7 +313,7 @@ class FieldMetadata(dict):
             ('sort',      {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Title Sort'),
                            'search_terms':['title_sort'],
@@ -306,7 +323,7 @@ class FieldMetadata(dict):
             ('size',      {'table':None,
                            'column':None,
                            'datatype':'float',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Size'),
                            'search_terms':['size'],
@@ -316,7 +333,7 @@ class FieldMetadata(dict):
             ('timestamp', {'table':None,
                            'column':None,
                            'datatype':'datetime',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Date'),
                            'search_terms':['date'],
@@ -326,7 +343,7 @@ class FieldMetadata(dict):
             ('title',     {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':_('Title'),
                            'search_terms':['title'],
@@ -336,7 +353,7 @@ class FieldMetadata(dict):
             ('uuid',      {'table':None,
                            'column':None,
                            'datatype':'text',
-                           'is_multiple':None,
+                           'is_multiple':{},
                            'kind':'field',
                            'name':None,
                            'search_terms':[],
@@ -374,6 +391,8 @@ class FieldMetadata(dict):
         self.get = self._tb_cats.get
 
     def __getitem__(self, key):
+        if key == 'title_sort':
+            return self._tb_cats['sort']
         return self._tb_cats[key]
 
     def __setitem__(self, key, val):
@@ -390,6 +409,8 @@ class FieldMetadata(dict):
         return self.has_key(key)
 
     def has_key(self, key):
+        if key == 'title_sort':
+            return True
         return key in self._tb_cats
 
     def keys(self):
@@ -504,7 +525,7 @@ class FieldMetadata(dict):
         if datatype == 'series':
             key += '_index'
             self._tb_cats[key] = {'table':None,        'column':None,
-                                 'datatype':'float',   'is_multiple':None,
+                                 'datatype':'float',   'is_multiple':{},
                                  'kind':'field',       'name':'',
                                  'search_terms':[key], 'label':label+'_index',
                                  'colnum':None,        'display':{},
@@ -556,7 +577,7 @@ class FieldMetadata(dict):
         if icu_lower(label) != label:
             st.append(icu_lower(label))
         self._tb_cats[label] = {'table':None,          'column':None,
-                                'datatype':None,       'is_multiple':None,
+                                'datatype':None,       'is_multiple':{},
                                 'kind':'user',         'name':name,
                                 'search_terms':st,     'is_custom':False,
                                 'is_category':True,    'is_csp': False}
@@ -566,7 +587,7 @@ class FieldMetadata(dict):
         if label in self._tb_cats:
             raise ValueError('Duplicate user field [%s]'%(label))
         self._tb_cats[label] = {'table':None,        'column':None,
-                                'datatype':None,     'is_multiple':None,
+                                'datatype':None,     'is_multiple':{},
                                 'kind':'search',     'name':name,
                                 'search_terms':[],   'is_custom':False,
                                 'is_category':True,  'is_csp': False}
