@@ -10,12 +10,13 @@ import re, os, posixpath
 import cherrypy
 
 from calibre import fit_image, guess_type
-from calibre.utils.date import fromtimestamp
+from calibre.utils.date import fromtimestamp, utcnow
 from calibre.library.caches import SortKeyGenerator
 from calibre.library.save_to_disk import find_plugboard
-
-from calibre.utils.magick.draw import save_cover_data_to, Image, \
-        thumbnail as generate_thumbnail
+from calibre.ebooks.metadata import authors_to_string
+from calibre.utils.magick.draw import (save_cover_data_to, Image,
+        thumbnail as generate_thumbnail)
+from calibre.utils.filenames import ascii_filename
 
 plugboard_content_server_value = 'content_server'
 plugboard_content_server_formats = ['epub']
@@ -46,7 +47,7 @@ class ContentServer(object):
     # Utility methods {{{
     def last_modified(self, updated):
         '''
-        Generates a local independent, english timestamp from a datetime
+        Generates a locale independent, english timestamp from a datetime
         object
         '''
         lm = updated.strftime('day, %d month %Y %H:%M:%S GMT')
@@ -151,14 +152,12 @@ class ContentServer(object):
         try:
             cherrypy.response.headers['Content-Type'] = 'image/jpeg'
             cherrypy.response.timeout = 3600
-            cover = self.db.cover(id, index_is_id=True, as_file=True)
+            cover = self.db.cover(id, index_is_id=True)
             if cover is None:
                 cover = self.default_cover
                 updated = self.build_time
             else:
-                with cover as f:
-                    updated = fromtimestamp(os.fstat(f.fileno()).st_mtime)
-                    cover = f.read()
+                updated = self.db.cover_last_modified(id, index_is_id=True)
             cherrypy.response.headers['Last-Modified'] = self.last_modified(updated)
 
             if thumbnail:
@@ -187,9 +186,9 @@ class ContentServer(object):
                 mode='rb')
         if fmt is None:
             raise cherrypy.HTTPError(404, 'book: %d does not have format: %s'%(id, format))
+        mi = self.db.get_metadata(id, index_is_id=True)
         if format == 'EPUB':
             # Get the original metadata
-            mi = self.db.get_metadata(id, index_is_id=True)
 
             # Get any EPUB plugboards for the content server
             plugboards = self.db.prefs.get('plugboards', {})
@@ -203,24 +202,22 @@ class ContentServer(object):
                 newmi = mi
 
             # Write the updated file
-            from tempfile import TemporaryFile
             from calibre.ebooks.metadata.meta import set_metadata
-            raw = fmt.read()
-            fmt = TemporaryFile()
-            fmt.write(raw)
-            fmt.seek(0)
             set_metadata(fmt, newmi, 'epub')
             fmt.seek(0)
 
         mt = guess_type('dummy.'+format.lower())[0]
         if mt is None:
             mt = 'application/octet-stream'
+        au = authors_to_string(mi.authors if mi.authors else [_('Unknown')])
+        title = mi.title if mi.title else _('Unknown')
+        fname = u'%s - %s_%s.%s'%(title[:30], au[:30], id, format.lower())
+        fname = ascii_filename(fname).replace('"', '_')
         cherrypy.response.headers['Content-Type'] = mt
+        cherrypy.response.headers['Content-Disposition'] = \
+                b'attachment; filename="%s"'%fname
         cherrypy.response.timeout = 3600
-        path = getattr(fmt, 'name', None)
-        if path and os.path.exists(path):
-            updated = fromtimestamp(os.stat(path).st_mtime)
-            cherrypy.response.headers['Last-Modified'] = self.last_modified(updated)
+        cherrypy.response.headers['Last-Modified'] = self.last_modified(utcnow())
         return fmt
     # }}}
 
