@@ -231,7 +231,8 @@ class MobileServer(object):
             book['size'] = human_readable(book['size'])
 
             aus = record[FM['authors']] if record[FM['authors']] else __builtin__._('Unknown')
-            authors = '|'.join([i.replace('|', ',') for i in aus.split(',')])
+            aut_is = CFM['authors']['is_multiple']
+            authors = aut_is['list_to_ui'].join([i.replace('|', ',') for i in aus.split(',')])
             book['authors'] = authors
             book['series_index'] = fmt_sidx(float(record[FM['series_index']]))
             book['series'] = record[FM['series']]
@@ -254,8 +255,10 @@ class MobileServer(object):
                     continue
                 if datatype == 'text' and CFM[key]['is_multiple']:
                     book[key] = concat(name,
-                                       format_tag_string(val, ',',
-                                                         no_tag_count=True))
+                                       format_tag_string(val,
+                                           CFM[key]['is_multiple']['ui_to_list'],
+                                           no_tag_count=True,
+                                           joinval=CFM[key]['is_multiple']['list_to_ui']))
                 else:
                     book[key] = concat(name, val)
 
