@@ -68,7 +68,7 @@ def strftime(fmt='%Y/%m/%d %H:%M:%S', dt=None):
     except:
         return _strftime(fmt, nowf().timetuple())
 
-def format_tag_string(tags, sep, ignore_max=False, no_tag_count=False):
+def format_tag_string(tags, sep, ignore_max=False, no_tag_count=False, joinval=', '):
     MAX = sys.maxint if ignore_max else tweaks['max_content_server_tags_shown']
     if tags:
         tlist = [t.strip() for t in tags.split(sep)]
@@ -78,10 +78,10 @@ def format_tag_string(tags, sep, ignore_max=False, no_tag_count=False):
     if len(tlist) > MAX:
         tlist = tlist[:MAX]+['...']
     if no_tag_count:
-        return ', '.join(tlist) if tlist else ''
+        return joinval.join(tlist) if tlist else ''
     else:
         return u'%s:&:%s'%(tweaks['max_content_server_tags_shown'],
-                     ', '.join(tlist)) if tlist else ''
+                     joinval.join(tlist)) if tlist else ''
 
 def quote(s):
     if isinstance(s, unicode):
