@@ -121,9 +121,12 @@ class SortedConcatenate(object):
             return None
         return self.sep.join(map(self.ans.get, sorted(self.ans.keys())))
 
-class SafeSortedConcatenate(SortedConcatenate):
+class SortedConcatenateBar(SortedConcatenate):
     sep = '|'
 
+class SortedConcatenateAmper(SortedConcatenate):
+    sep = '&'
+
 class IdentifiersConcat(object):
     '''String concatenation aggregator for the identifiers map'''
     def __init__(self):
@@ -141,9 +144,9 @@ class AumSortedConcatenate(object):
     def __init__(self):
         self.ans = {}
 
-    def step(self, ndx, author, sort):
+    def step(self, ndx, author, sort, link):
         if author is not None:
-            self.ans[ndx] = author + ':::' + sort
+            self.ans[ndx] = ':::'.join((author, sort, link))
 
     def finalize(self):
         keys = self.ans.keys()
@@ -220,12 +223,13 @@ class DBThread(Thread):
         self.conn.execute('pragma cache_size=5000')
         encoding = self.conn.execute('pragma encoding').fetchone()[0]
         self.conn.create_aggregate('sortconcat', 2, SortedConcatenate)
-        self.conn.create_aggregate('sort_concat', 2, SafeSortedConcatenate)
+        self.conn.create_aggregate('sortconcat_bar', 2, SortedConcatenateBar)
+        self.conn.create_aggregate('sortconcat_amper', 2, SortedConcatenateAmper)
         self.conn.create_aggregate('identifiers_concat', 2, IdentifiersConcat)
         load_c_extensions(self.conn)
         self.conn.row_factory = sqlite.Row if self.row_factory else  lambda cursor, row : list(row)
         self.conn.create_aggregate('concat', 1, Concatenate)
-        self.conn.create_aggregate('aum_sortconcat', 3, AumSortedConcatenate)
+        self.conn.create_aggregate('aum_sortconcat', 4, AumSortedConcatenate)
         self.conn.create_collation('PYNOCASE', partial(pynocase,
             encoding=encoding))
         self.conn.create_function('title_sort', 1, title_sort)
