@@ -10,7 +10,7 @@ import sys
 from functools import partial
 
 from calibre.constants import plugins
-from calibre.utils.config import tweaks
+from calibre.utils.config_base import tweaks
 
 _icu = _collator = None
 _locale = None
