@@ -10,6 +10,7 @@ import os
 
 from calibre.customize.conversion import InputFormatPlugin, OptionRecommendation
 from calibre.constants import numeric_version
+from calibre import walk
 
 class RecipeDisabled(Exception):
     pass
@@ -111,6 +112,10 @@ class RecipeInput(InputFormatPlugin):
             if f.endswith('.opf'):
                 return os.path.abspath(f)
 
+        for f in walk('.'):
+            if f.endswith('.opf'):
+                return os.path.abspath(f)
+
     def postprocess_book(self, oeb, opts, log):
         if self.recipe_object is not None:
             self.recipe_object.postprocess_book(oeb, opts, log)
