@@ -841,11 +841,19 @@ ol, ul { padding-left: 2em; }
             self.styledict[name] = styles
         # Write the styles to HTML
         self.writeout(self.default_styles)
+        # Changed by Kovid to not write out endless copies of the same style
+        css_styles = {}
         for name in self.stylestack:
             styles = self.styledict.get(name)
-            css2 = self.cs.convert_styles(styles)
-            self.writeout("%s {\n" % name)
-            for style, val in css2.items():
+            css2 = tuple(self.cs.convert_styles(styles).iteritems())
+            if css2 in css_styles:
+                css_styles[css2].append(name)
+            else:
+                css_styles[css2] = [name]
+
+        for css2, names in css_styles.iteritems():
+            self.writeout("%s {\n" % ', '.join(names))
+            for style, val in css2:
                 self.writeout("\t%s: %s;\n" % (style, val) )
             self.writeout("}\n")
 
@@ -1386,12 +1394,19 @@ ol, ul { padding-left: 2em; }
         self.purgedata()
 
     def s_text_s(self, tag, attrs):
-        """ Generate a number of spaces. ODF has an element; HTML uses &nbsp;
-            We use &#160; so we can send the output through an XML parser if we desire to
+        # Changed by Kovid to fix non breaking spaces being prepended to
+        # element instead of being part of the text flow.
+        # We don't use an entity for the nbsp as the contents of self.data will
+        # be escaped on writeout.
+        """ Generate a number of spaces. We use the non breaking space for
+        the text:s ODF element.
         """
-        c = attrs.get( (TEXTNS,'c'),"1")
-        for x in xrange(int(c)):
-            self.writeout('&#160;')
+        try:
+            c = int(attrs.get((TEXTNS, 'c'), 1))
+        except:
+            c = 0
+        if c > 0:
+            self.data.append(u'\u00a0'*c)
 
     def s_text_span(self, tag, attrs):
         """ The <text:span> element matches the <span> element in HTML. It is
@@ -1400,18 +1415,34 @@ ol, ul { padding-left: 2em; }
         self.writedata()
         c = attrs.get( (TEXTNS,'style-name'), None)
         htmlattrs = {}
+        # Changed by Kovid to handle inline special styles defined on <text:span> tags.
+        # Apparently LibreOffice does this.
+        special = 'span'
         if c:
             c = c.replace(".","_")
             special = special_styles.get("S-"+c)
-            if special is None and self.generate_css:
-                htmlattrs['class'] = "S-%s" % c
-        self.opentag('span', htmlattrs)
+            if special is None:
+                special = 'span'
+                if self.generate_css:
+                    htmlattrs['class'] = "S-%s" % c
+
+        self.opentag(special, htmlattrs)
         self.purgedata()
 
     def e_text_span(self, tag, attrs):
         """ End the <text:span> """
         self.writedata()
-        self.closetag('span', False)
+        c = attrs.get( (TEXTNS,'style-name'), None)
+        # Changed by Kovid to handle inline special styles defined on <text:span> tags.
+        # Apparently LibreOffice does this.
+        special = 'span'
+        if c:
+            c = c.replace(".","_")
+            special = special_styles.get("S-"+c)
+            if special is None:
+                special = 'span'
+
+        self.closetag(special, False)
         self.purgedata()
 
     def s_text_tab(self, tag, attrs):
